<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="432"/>
        <source>Add files to the current archive</source>
        <translation>Bestanden toevoegen aan huidig archief</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="437"/>
        <source>Use password</source>
        <translation>Wachtwoord gebruiken</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="136"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>Het oorspronkelijke bestand van ‘%1’ bestaat niet. Loop alles na en probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="138"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 is niet aanwezig op de schijf. Controleer het bestand en probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="147"/>
        <source>You do not have permission to compress %1</source>
        <translation>Je bent niet bevoegd om %1 in te pakken</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>Bezig met bijwerken van opmerking…</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="76"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>Please add files</source>
        <translation>Voeg bestanden toe</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="143"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="226"/>
        <source>New Archive</source>
        <translation>Nieuw archief</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="204"/>
        <source>Advanced Options</source>
        <translation>Geavanceerde opties</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="208"/>
        <source>Compression method</source>
        <translation>Inpakmethode</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Encrypt the archive</source>
        <translation>Archief versleutelen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="213"/>
        <source>CPU threads</source>
        <translation>Aantal cpu-kernen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="215"/>
        <source>Encrypt the file list too</source>
        <translation>Bestandslijst eveneens versleutelen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="217"/>
        <source>Split to volumes</source>
        <translation>Opsplitsen in volumes</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="219"/>
        <source>Comment</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="221"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Inpakken</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Store</source>
        <translation>Opslag</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fastest</source>
        <translation>Snelste</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fast</source>
        <translation>Snel</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Normal</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Good</source>
        <translation>Goed</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Best</source>
        <translation>Beste</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>Single thread</source>
        <translation>Eén kern</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>2 threads</source>
        <translation>2 kernen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>4 threads</source>
        <translation>4 kernen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>8 threads</source>
        <translation>8 kernen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="257"/>
        <source>Support zip, 7z type only</source>
        <translation>Alleen zip en 7z worden ondersteund</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support 7z type only</source>
        <translation>Alleen 7z wordt ondersteund</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="272"/>
        <source>Enter up to %1 characters</source>
        <translation>Voer maximaal %1 tekens in</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="293"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="294"/>
        <source>Save to</source>
        <translation>Opslaan in</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="483"/>
        <source>Invalid file name</source>
        <translation>Ongeldige bestandsnaam</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Please enter the path</source>
        <translation>Voer het pad in</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="494"/>
        <source>The path does not exist, please retry</source>
        <translation>Het pad bestaat niet. Probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="499"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Je bent niet bevoegd om hier bestanden op te slaan. Kies een andere locatie.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="507"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Te veel schijven - pas aan en probeer opnieuw</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="516"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="544"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 is niet aanwezig op de schijf. Controleer het bestand en probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="551"/>
        <source>You do not have permission to compress %1</source>
        <translation>Je bent niet bevoegd om %1 in te pakken</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="542"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>Het oorspronkelijke bestand van ‘%1’ bestaat niet. Loop alles na en probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="577"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Vervangen</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="691"/>
        <source>Total size: %1</source>
        <translation>Totale grootte: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="711"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>De naam is dezelfde als die van een ander archief. Kies een andere naam.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="719"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>Wachtwoorden van zip-archieven mogen niet in het Chinees zijn</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Er is al een bestand met deze naam. Wil je het vervangen?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="823"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Bestandsnamen mogen alleen Chinese, Engelse en Nederlandse tekens bevatten</translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="284"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="298"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="301"/>
        <source>Open with</source>
        <translation>Openen met</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="305"/>
        <location filename="../src/source/tree/compressview.cpp" line="407"/>
        <source>Select default program</source>
        <translation>Standaardprogramma kiezen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>De bestanden worden permanent verwijderd. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <location filename="../src/source/tree/compressview.cpp" line="381"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="382"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="380"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>Wil je het archief toevoegen aan de lijst of openen in een nieuw venster?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="383"/>
        <source>Open in new window</source>
        <translation>Openen in nieuw venster</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="306"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>Archieven van dit bestandstype kunnen niet worden aangepast. Zet het archief om om de aanpassingen op te slaan.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="314"/>
        <source>Convert the format to:</source>
        <translation>Omzetten naar:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="338"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="339"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Converteren</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>item(s)</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>Het uitpakken is mislukt</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>Uitpakken mislukt: bestand is beschadigd.</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Opnieuw proberen</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Sleep een bestand of map hierheen</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Bestand kiezen</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>Het archief is beschadigd</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>Openen als alleen-lezen</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Bezig met laden…</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <location filename="../src/main.cpp" line="61"/>
        <source>Archive Manager</source>
        <translation>Archiefbeheer</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>Archiefbeheer is een snel en licht programma om archieven mee samen te stellen en uit te pakken.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="172"/>
        <location filename="../src/source/mainwindow.cpp" line="191"/>
        <location filename="../src/source/mainwindow.cpp" line="440"/>
        <source>Open file</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="173"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="294"/>
        <location filename="../src/source/mainwindow.cpp" line="304"/>
        <source>Create New Archive</source>
        <translation>Archief samenstellen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="345"/>
        <source>Converting</source>
        <translation>Bezig met omzetten</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="352"/>
        <source>Updating comments</source>
        <translation>Bezig met bijwerken van opmerkingen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <location filename="../src/source/mainwindow.cpp" line="2090"/>
        <location filename="../src/source/mainwindow.cpp" line="2115"/>
        <source>Plugin error</source>
        <translation>Plug-infout</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1302"/>
        <source>Adding successful</source>
        <translation>Toegevoegd</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2139"/>
        <source>No data in it</source>
        <translation>Het archief is blanco</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1522"/>
        <source>Adding canceled</source>
        <translation>Toevoegen afgebroken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1620"/>
        <source>Adding failed</source>
        <translation>Toevoegen mislukt</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1673"/>
        <source>Extraction failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1700"/>
        <location filename="../src/source/mainwindow.cpp" line="2135"/>
        <source>Failed to create &quot;%1&quot;</source>
        <translation>‘%1’ kan niet worden aangemaakt</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1822"/>
        <source>Open failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2041"/>
        <source>Compression successful</source>
        <translation>Inpakken voltooid</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2047"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2076"/>
        <location filename="../src/source/mainwindow.cpp" line="2143"/>
        <source>Insufficient disk space</source>
        <translation>Onvoldoende vrije schijfruimte</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2102"/>
        <location filename="../src/source/mainwindow.cpp" line="2123"/>
        <source>Some volumes are missing</source>
        <translation>Enkele schijven ontbreken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2127"/>
        <source>Wrong password, please retry</source>
        <translation>Onjuist wachtwoord - probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2131"/>
        <location filename="../src/source/mainwindow.cpp" line="2155"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2152"/>
        <source>Conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2290"/>
        <source>Select file</source>
        <translation>Bestand kiezen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3102"/>
        <source>Enter up to %1 characters</source>
        <translation>Voer maximaal %1 tekens in</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="196"/>
        <location filename="../src/source/mainwindow.cpp" line="2978"/>
        <source>File info</source>
        <translation>Bestandsinformatie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Do you want to delete the archive?</source>
        <translation>Wil je het archief verwijderen?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="553"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>%1 is ondertussen aangepast. Open het bestand opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="73"/>
        <source>Archive Manager</source>
        <translation>Archiefbeheer</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Je bent niet bevoegd om hier bestanden op te slaan. Kies een andere locatie.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="317"/>
        <source>Adding files to %1</source>
        <translation>Bezig met toevoegen aan %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="324"/>
        <source>Compressing</source>
        <translation>Bezig met inpakken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="331"/>
        <source>Extracting</source>
        <translation>Bezig met uitpakken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="338"/>
        <source>Deleting</source>
        <translation>Bezig met verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="443"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="513"/>
        <location filename="../src/source/mainwindow.cpp" line="2802"/>
        <source>Loading, please wait...</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>Weet je zeker dat je de taak wilt afbreken?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1308"/>
        <location filename="../src/source/mainwindow.cpp" line="1434"/>
        <source>Updating, please wait...</source>
        <translation>Bezig met bijwerken…</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1695"/>
        <source>File name too long</source>
        <translation>De bestandsnaam is te lang</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2072"/>
        <source>Failed to create file</source>
        <translation>Het bestand kan niet worden aangemaakt</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2065"/>
        <source>Compression failed</source>
        <translation>Het inpakken is mislukt</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Vervangen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2464"/>
        <source>Find directory</source>
        <translation>Map zoeken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2087"/>
        <source>Open failed</source>
        <translation>Openen mislukt</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1616"/>
        <location filename="../src/source/mainwindow.cpp" line="1690"/>
        <location filename="../src/source/mainwindow.cpp" line="1765"/>
        <location filename="../src/source/mainwindow.cpp" line="1820"/>
        <location filename="../src/source/mainwindow.cpp" line="2098"/>
        <source>Wrong password</source>
        <translation>Onjuist wachtwoord</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="659"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>Dit bestandsformaat wordt niet ondersteund</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="556"/>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="666"/>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <location filename="../src/source/mainwindow.cpp" line="2722"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <source>You do not have permission to load %1</source>
        <translation>Je bent niet bevoegd om %1 te laden</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <source>No such file or directory</source>
        <translation>Bestand of map bestaat niet</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1350"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>Uitpakken voltooid</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1543"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>Uitpakken afgebroken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1685"/>
        <location filename="../src/source/mainwindow.cpp" line="1760"/>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>The archive is damaged</source>
        <translation>Het archief is beschadigd</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2045"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>Uitpakken voltooid</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2051"/>
        <source>Conversion successful</source>
        <translation>Omzetten voltooid</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2112"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>Het uitpakken is mislukt</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2282"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2286"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2294"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2302"/>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2314"/>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2392"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>De naam is dezelfde als die van een ander archief. Kies een andere naam.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Er is al een bestand met deze naam. Wil je het vervangen?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2543"/>
        <source>You cannot add the archive to itself</source>
        <translation>Je kunt het archief niet toevoegen aan hetzelfde archief</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>Je kunt geen bestanden toevoegen aan archieven met dit bestandstype.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Bijwerken</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3002"/>
        <source>Basic info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3018"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3019"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3020"/>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3021"/>
        <source>Time created</source>
        <translation>Gemaakt om</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3022"/>
        <source>Time accessed</source>
        <translation>Geopend om</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3023"/>
        <source>Time modified</source>
        <translation>Aangepast om</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3033"/>
        <source>Archive</source>
        <translation>Archief</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3064"/>
        <source>Comment</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="656"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Controleer de bestandstoewijzing in de instellingen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>Het archief is ondertussen aangepast. Open het opnieuw.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Map</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Afbeelding</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Archief</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>Uitvoerbaar bestand</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Document</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Reservekopiebestand</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Openen met</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Ander programma kiezen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Instellen als standaard</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Aanbevolen programma&apos;s</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Andere programma&apos;s</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Het bestand is versleuteld - voer het wachtwoord in.</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Huidig pad:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Terug naar ‘%1’</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>Er is/zijn %1 lopende taak/taken</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="102"/>
        <source>Task</source>
        <translation>Taak</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="113"/>
        <source>Extracting</source>
        <translation>Bezig met uitpakken</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>Weet je zeker dat je het uitpakken wilt afbreken?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ja</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="314"/>
        <location filename="../src/source/page/progresspage.cpp" line="317"/>
        <location filename="../src/source/page/progresspage.cpp" line="320"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Snelheid</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="149"/>
        <source>Calculating...</source>
        <translation>Bezig met berekenen…</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="324"/>
        <location filename="../src/source/page/progresspage.cpp" line="326"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Snelheid</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="338"/>
        <location filename="../src/source/page/progresspage.cpp" line="340"/>
        <location filename="../src/source/page/progresspage.cpp" line="342"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Snelheid</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="330"/>
        <location filename="../src/source/page/progresspage.cpp" line="332"/>
        <location filename="../src/source/page/progresspage.cpp" line="334"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Snelheid</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="310"/>
        <source>Time left</source>
        <translation>Resterende tijd</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="122"/>
        <source>Compressing</source>
        <translation>Bezig met inpakken</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="124"/>
        <source>Deleting</source>
        <translation>Bezig met verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="126"/>
        <source>Converting</source>
        <translation>Bezig met omzetten</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="128"/>
        <location filename="../src/source/page/progresspage.cpp" line="147"/>
        <source>Updating the comment...</source>
        <translation>Bezig met bijwerken van opmerking…</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="130"/>
        <source>Extracting</source>
        <translation>Bezig met uitpakken</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <location filename="../src/source/page/progresspage.cpp" line="178"/>
        <location filename="../src/source/page/progresspage.cpp" line="358"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Onderbreken</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="177"/>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="354"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="376"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>Weet je zeker dat je het uitpakken wilt afbreken?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="378"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>Weet je zeker dat je de verwijdering wilt afbreken?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="374"/>
        <location filename="../src/source/page/progresspage.cpp" line="380"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>Weet je zeker dat je het inpakken wilt afbreken?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="382"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>Weet je zeker dat je het omzetten wilt afbreken?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Aangepast op</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2821"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>%1 is aangepast. Wil je de aanpassingen opslaan?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Uitpakken</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Automatisch een map aanmaken bij het uitpakken van meerdere bestanden</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>Uitgepakte bestanden tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Bestandsbeheer</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>Bestanden na comprimeren verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Bestandstoewijzingen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Bestandstype</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="202"/>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <location filename="../3rdparty/interface/queries.cpp" line="244"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Overslaan</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="203"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Samenvoegen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <location filename="../3rdparty/interface/queries.cpp" line="221"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Er is al een bestand met deze naam. Wil je het vervangen?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <location filename="../3rdparty/interface/queries.cpp" line="245"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Vervangen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="477"/>
        <location filename="../3rdparty/interface/queries.cpp" line="405"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="478"/>
        <location filename="../3rdparty/interface/queries.cpp" line="406"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="200"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Er is al een map met deze naam. Wil je deze vervangen?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <location filename="../3rdparty/interface/queries.cpp" line="226"/>
        <source>Apply to all</source>
        <translation>Toepassen op alles</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="195"/>
        <source>Current directory</source>
        <translation>Huidige map</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Alles wissen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>Aanbevolen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Archieven uitpakken naar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="205"/>
        <source>Other directory</source>
        <translation>Andere map</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="200"/>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Archieven na uitpakken verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="299"/>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="302"/>
        <source>Ask for confirmation</source>
        <translation>Vragen om bevestiging</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="305"/>
        <source>Always</source>
        <translation>Altijd</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>Inpakken voltooid</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="87"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="116"/>
        <source>Extract to:</source>
        <translation>Uitpakken in:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Uitpakken</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="191"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>Het standaardpad bestaat niet. Probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Je bent niet bevoegd om hier bestanden op te slaan. Kies een andere locatie.</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="197"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="211"/>
        <source>Find directory</source>
        <translation>Map zoeken</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>You cannot add the archive to itself</source>
        <translation>Je kunt het archief niet toevoegen aan hetzelfde archief</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="618"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Uitpakken</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="620"/>
        <source>Extract to current directory</source>
        <translation>Uitpakken in huidige map</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="622"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="625"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="632"/>
        <source>Open with</source>
        <translation>Openen met</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="636"/>
        <location filename="../src/source/tree/uncompressview.cpp" line="737"/>
        <source>Select default program</source>
        <translation>Standaardprogramma kiezen</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>Weet je zeker dat je de geselecteerde bestanden wilt verwijderen?</translation>
    </message>
</context>
</TS>
